@@ -2,7 +2,6 @@ package ecr
 
 import (
 	"github.com/hashicorp/waypoint/builtin/docker"
-	"google.golang.org/protobuf/types/known/emptypb"
 )
 
 // ECRImageMapper maps a ecr.Image to a docker.Image structure.
@@ -12,7 +11,7 @@ func ECRImageMapper(src *Image) *docker.Image {
 		Tag:   src.Tag,
 
 		Location: &docker.Image_Registry{
-			Registry: &emptypb.Empty{},
+			Registry: &docker.Image_RegistryLocation{},
 		},
 	}
 }
