@@ -24,7 +24,13 @@ type OptionsWithContext = RunOptions & ContextObject;
 // for more:
 // https://github.com/dequelabs/axe-core/blob/develop/doc/API.md#include-exclude-object
 const include = [['#ember-testing-container']];
-const exclude = [['.pds-logomark'], ['.pds-tabNav'], ['.card-header'], ['.x-toggle-btn']];
+const exclude = [
+  ['.pds-logomark'],
+  ['.pds-tabNav'],
+  ['.card-header'],
+  ['.x-toggle-btn'],
+  ['.flight-sprite-container'],
+];
 
 export function setup(): void {
   setupGlobalA11yHooks(() => true, { helpers: A11Y_TEST_HELPER_NAMES });
